diff --git a/docs/LangRef.html b/docs/LangRef.html
index 23558e7f25c..e205dc29492 100644
--- a/docs/LangRef.html
+++ b/docs/LangRef.html
@@ -111,7 +111,7 @@
Finally, some targets may provide defined semantics when
using the value as the operand to an inline assembly, but that is target
@@ -2541,7 +2541,7 @@ Instructions
'ret' instruction, the
'br' instruction, the
'switch' instruction, the
- ''indbr' Instruction, the
+ ''indirectbr' Instruction, the
'invoke' instruction, the
'unwind' instruction, and the
'unreachable' instruction.
@@ -2703,19 +2703,19 @@ IfUnequal:
Syntax:
- indbr <somety>* <address>, [ label <dest1>, label <dest2>, ... ]
+ indirectbr <somety>* <address>, [ label <dest1>, label <dest2>, ... ]
Overview:
-
The 'indbr' instruction implements an indirect branch to a label
+
The 'indirectbr' instruction implements an indirect branch to a label
within the current function, whose address is specified by
"address". Address must be derived from a blockaddress constant.
@@ -2743,7 +2743,7 @@ IfUnequal:
Example:
- indbr i8* %Addr, [ label %bb1, label %bb2, label %bb3 ]
+ indirectbr i8* %Addr, [ label %bb1, label %bb2, label %bb3 ]
diff --git a/include/llvm/Bitcode/LLVMBitCodes.h b/include/llvm/Bitcode/LLVMBitCodes.h
index 7cadd5807fa..abe9966aa0a 100644
--- a/include/llvm/Bitcode/LLVMBitCodes.h
+++ b/include/llvm/Bitcode/LLVMBitCodes.h
@@ -237,7 +237,7 @@ namespace bitc {
// new select on i1 or [N x i1]
FUNC_CODE_INST_VSELECT = 29, // VSELECT: [ty,opval,opval,predty,pred]
FUNC_CODE_INST_INBOUNDS_GEP= 30, // INBOUNDS_GEP: [n x operands]
- FUNC_CODE_INST_INDBR = 31 // INDBR: [opty, op0, op1, ...]
+ FUNC_CODE_INST_INDIRECTBR = 31 // INDIRECTBR: [opty, op0, op1, ...]
};
} // End bitc namespace
} // End llvm namespace
diff --git a/include/llvm/Instruction.def b/include/llvm/Instruction.def
index c0adf40316b..205f30313e7 100644
--- a/include/llvm/Instruction.def
+++ b/include/llvm/Instruction.def
@@ -97,7 +97,7 @@
HANDLE_TERM_INST ( 1, Ret , ReturnInst)
HANDLE_TERM_INST ( 2, Br , BranchInst)
HANDLE_TERM_INST ( 3, Switch , SwitchInst)
-HANDLE_TERM_INST ( 4, IndBr , IndBrInst)
+HANDLE_TERM_INST ( 4, IndirectBr , IndirectBrInst)
HANDLE_TERM_INST ( 5, Invoke , InvokeInst)
HANDLE_TERM_INST ( 6, Unwind , UnwindInst)
HANDLE_TERM_INST ( 7, Unreachable, UnreachableInst)
diff --git a/include/llvm/Instructions.h b/include/llvm/Instructions.h
index ac194337357..28854dfe033 100644
--- a/include/llvm/Instructions.h
+++ b/include/llvm/Instructions.h
@@ -2220,61 +2220,61 @@ DEFINE_TRANSPARENT_OPERAND_ACCESSORS(SwitchInst, Value)
//===----------------------------------------------------------------------===//
-// IndBrInst Class
+// IndirectBrInst Class
//===----------------------------------------------------------------------===//
//===---------------------------------------------------------------------------
/// IndBrInst - Indirect Branch Instruction.
///
-class IndBrInst : public TerminatorInst {
+class IndirectBrInst : public TerminatorInst {
void *operator new(size_t, unsigned); // DO NOT IMPLEMENT
unsigned ReservedSpace;
// Operand[0] = Value to switch on
// Operand[1] = Default basic block destination
// Operand[2n ] = Value to match
// Operand[2n+1] = BasicBlock to go to on match
- IndBrInst(const IndBrInst &IBI);
+ IndirectBrInst(const IndirectBrInst &IBI);
void init(Value *Address, unsigned NumDests);
void resizeOperands(unsigned No);
// allocate space for exactly zero operands
void *operator new(size_t s) {
return User::operator new(s, 0);
}
/// IndBrInst ctor - Create a new indbr instruction, specifying an Address to
/// jump to. The number of expected destinations can be specified here to
/// make memory allocation more efficient. This constructor can also
/// autoinsert before another instruction.
- IndBrInst(Value *Address, unsigned NumDests, Instruction *InsertBefore);
+ IndirectBrInst(Value *Address, unsigned NumDests, Instruction *InsertBefore);
- /// IndBrInst ctor - Create a new indbr instruction, specifying an Address to
- /// jump to. The number of expected destinations can be specified here to
- /// make memory allocation more efficient. This constructor also autoinserts
- /// at the end of the specified BasicBlock.
- IndBrInst(Value *Address, unsigned NumDests, BasicBlock *InsertAtEnd);
+ /// IndirectBrInst ctor - Create a new indirectbr instruction, specifying an
+ /// Address to jump to. The number of expected destinations can be specified
+ /// here to make memory allocation more efficient. This constructor also
+ /// autoinserts at the end of the specified BasicBlock.
+ IndirectBrInst(Value *Address, unsigned NumDests, BasicBlock *InsertAtEnd);
protected:
- virtual IndBrInst *clone_impl() const;
+ virtual IndirectBrInst *clone_impl() const;
public:
- static IndBrInst *Create(Value *Address, unsigned NumDests,
- Instruction *InsertBefore = 0) {
- return new IndBrInst(Address, NumDests, InsertBefore);
+ static IndirectBrInst *Create(Value *Address, unsigned NumDests,
+ Instruction *InsertBefore = 0) {
+ return new IndirectBrInst(Address, NumDests, InsertBefore);
}
- static IndBrInst *Create(Value *Address, unsigned NumDests,
- BasicBlock *InsertAtEnd) {
- return new IndBrInst(Address, NumDests, InsertAtEnd);
+ static IndirectBrInst *Create(Value *Address, unsigned NumDests,
+ BasicBlock *InsertAtEnd) {
+ return new IndirectBrInst(Address, NumDests, InsertAtEnd);
}
- ~IndBrInst();
+ ~IndirectBrInst();
/// Provide fast operand accessors.
DECLARE_TRANSPARENT_OPERAND_ACCESSORS(Value);
// Accessor Methods for IndBr instruction.
Value *getAddress() { return getOperand(0); }
const Value *getAddress() const { return getOperand(0); }
void setAddress(Value *V) { setOperand(0, V); }
/// getNumDestinations - return the number of possible destinations in this
- /// indbr instruction.
+ /// indirectbr instruction.
unsigned getNumDestinations() const { return getNumOperands()-1; }
/// getDestination - Return the specified destination.
@@ -2286,7 +2286,7 @@ public:
void addDestination(BasicBlock *Dest);
/// removeDestination - This method removes the specified successor from the
- /// indbr instruction.
+ /// indirectbr instruction.
void removeDestination(unsigned i);
unsigned getNumSuccessors() const { return getNumOperands()-1; }
@@ -2298,9 +2298,9 @@ public:
}
// Methods for support type inquiry through isa, cast, and dyn_cast:
- static inline bool classof(const IndBrInst *) { return true; }
+ static inline bool classof(const IndirectBrInst *) { return true; }
static inline bool classof(const Instruction *I) {
- return I->getOpcode() == Instruction::IndBr;
+ return I->getOpcode() == Instruction::IndirectBr;
}
static inline bool classof(const Value *V) {
return isa
@@ -2220,61 +2220,61 @@ DEFINE_TRANSPARENT_OPERAND_ACCESSORS(SwitchInst, Value)
//===----------------------------------------------------------------------===//
//===---------------------------------------------------------------------------
-/// IndBrInst - Indirect Branch Instruction.
+/// IndirectBrInst - Indirect Branch Instruction.
///
@@ -2220,61 +2220,61 @@ DEFINE_TRANSPARENT_OPERAND_ACCESSORS(SwitchInst, Value)
return User::operator new(s, 0);
}
- /// IndBrInst ctor - Create a new indbr instruction, specifying an Address to
- /// jump to. The number of expected destinations can be specified here to
- /// make memory allocation more efficient. This constructor can also
+ /// IndirectBrInst ctor - Create a new indirectbr instruction, specifying an
+ /// Address to jump to. The number of expected destinations can be specified
+ /// here to make memory allocation more efficient. This constructor can also
/// autoinsert before another instruction.
@@ -2220,61 +2220,61 @@ DEFINE_TRANSPARENT_OPERAND_ACCESSORS(SwitchInst, Value)
/// Provide fast operand accessors.
DECLARE_TRANSPARENT_OPERAND_ACCESSORS(Value);
- // Accessor Methods for IndBr instruction.
+ // Accessor Methods for IndirectBrInst instruction.
Value *getAddress() { return getOperand(0); }
const Value *getAddress() const { return getOperand(0); }